<?php /*

**************************************************************************

Plugin Name:  重新生成缩略图
Description:  重新生成一个或多个图像上载的缩略图。更改其大小时非常有用。
Plugin URI:   https://alex.blog/gechiui-plugins/regenerate-thumbnails/
Version:      3.1.5
Author:       Alex Mills (Viper007Bond)
Author URI:   https://alex.blog/
Text Domain:  regenerate-thumbnails
License:      GPL2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html

**************************************************************************

Regenerate Thumbnails is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.

Regenerate Thumbnails is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Regenerate Thumbnails. If not, see https://www.gnu.org/licenses/gpl-2.0.html.

**************************************************************************/

/**
 * Main plugin class.
 *
 * @since 1.0.0
 */
class RegenerateThumbnails {
	/**
	 * This plugin's version number. Used for busting caches.
	 *
	 * @var string
	 */
	public $version = '3.1.5';

	/**
	 * The menu ID of this plugin, as returned by add_management_page().
	 *
	 * @var string
	 */
	public $menu_id;

	/**
	 * The capability required to use this plugin.
	 * Please don't change this directly. Use the "regenerate_thumbs_cap" filter instead.
	 *
	 * @var string
	 */
	public $capability = 'manage_options';

	/**
	 * The instance of the REST API controller class used to extend the REST API.
	 *
	 * @var RegenerateThumbnails_REST_Controller
	 */
	public $rest_api;

	/**
	 * The single instance of this plugin.
	 *
	 * @see    RegenerateThumbnails()
	 *
	 * @access private
	 * @var    RegenerateThumbnails
	 */
	private static $instance;

	/**
	 * Constructor. Doesn't actually do anything as instance() creates the class instance.
	 */
	private function __construct() {}

	/**
	 * Prevents the class from being cloned.
	 */
	public function __clone() {
		gc_die( "Please don't clone RegenerateThumbnails" );
	}

	/**
	 * Prints the class from being unserialized and woken up.
	 */
	public function __wakeup() {
		gc_die( "Please don't unserialize/wakeup RegenerateThumbnails" );
	}

	/**
	 * Creates a new instance of this class if one hasn't already been made
	 * and then returns the single instance of this class.
	 *
	 * @return RegenerateThumbnails
	 */
	public static function instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new RegenerateThumbnails;
			self::$instance->setup();
		}

		return self::$instance;
	}

	/**
	 * Register all of the needed hooks and actions.
	 */
	public function setup() {
		// Prevent fatals on old versions of GeChiUI
		if ( ! class_exists( 'GC_REST_Controller' ) ) {
			return;
		}

		require dirname( __FILE__ ) . '/includes/class-regeneratethumbnails-regenerator.php';
		require dirname( __FILE__ ) . '/includes/class-regeneratethumbnails-rest-controller.php';

		// Allow people to change what capability is required to use this plugin.
		$this->capability = apply_filters( 'regenerate_thumbs_cap', $this->capability );

		// Initialize the REST API routes.
		add_action( 'rest_api_init', array( $this, 'rest_api_init' ) );

		// Add a new item to the Tools menu in the admin menu.
		add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );

		// Load the required JavaScript and CSS.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueues' ) );

		// For the bulk action dropdowns.
		add_action( 'admin_head-upload.php', array( $this, 'add_bulk_actions_via_javascript' ) );
		add_action( 'admin_action_bulk_regenerate_thumbnails', array( $this, 'bulk_action_handler' ) ); // Top drowndown.
		add_action( 'admin_action_-1', array( $this, 'bulk_action_handler' ) ); // Bottom dropdown.

		// Add a regenerate button to the non-modal edit media page.
		add_action( 'attachment_submitbox_misc_actions', array( $this, 'add_button_to_media_edit_page' ), 99 );

		// Add a regenerate button to the list of fields in the edit media modal.
		// Ideally this would with the action links but I'm not good enough with JavaScript to do it.
		add_filter( 'attachment_fields_to_edit', array( $this, 'add_button_to_edit_media_modal_fields_area' ), 99, 2 );

		// Add a regenerate link to actions list in the media list view.
		add_filter( 'media_row_actions', array( $this, 'add_regenerate_link_to_media_list_view' ), 10, 2 );
	}

	/**
	 * Initialize the REST API routes.
	 */
	public function rest_api_init() {
		$this->rest_api = new RegenerateThumbnails_REST_Controller();
		$this->rest_api->register_routes();
		$this->rest_api->register_filters();
	}

	/**
	 * Adds a the new item to the admin menu.
	 */
	public function add_admin_menu() {
		$this->menu_id = add_management_page(
			_x( '重新生成缩略图', 'admin page title', 'regenerate-thumbnails' ),
			_x( '重新生成缩略图', 'admin menu entry title', 'regenerate-thumbnails' ),
			$this->capability,
			'regenerate-thumbnails',
			array( $this, 'regenerate_interface' )
		);

		add_action( 'admin_head-' . $this->menu_id, array( $this, 'add_admin_notice_if_resizing_not_supported' ) );
	}

	/**
	 * Enqueues the requires JavaScript file and stylesheet on the plugin's admin page.
	 *
	 * @param string $hook_suffix The current page's hook suffix as provided by admin-header.php.
	 */
	public function admin_enqueues( $hook_suffix ) {
		if ( $hook_suffix != $this->menu_id ) {
			return;
		}

		// Pre-4.9 compatibility.
		if ( ! gc_script_is( 'gc-api-request', 'registered' ) ) {
			gc_register_script(
				'gc-api-request',
				plugins_url( 'js/api-request.min.js', __FILE__ ),
				array( 'jquery' ),
				'4.9',
				true
			);

			gc_localize_script( 'gc-api-request', 'gcApiSettings', array(
				'root'          => esc_url_raw( get_rest_url() ),
				'nonce'         => ( gc_installing() && ! is_multisite() ) ? '' : gc_create_nonce( 'gc_rest' ),
				'versionString' => 'gc/v2/',
			) );
		}

		gc_enqueue_script(
			'regenerate-thumbnails',
			plugins_url( 'dist/build.js', __FILE__ ),
			array( 'gc-api-request' ),
			( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? filemtime( dirname( __FILE__ ) . '/dist/build.js' ) : $this->version,
			true
		);

		// phpcs:disable GeChiUI.Arrays.MultipleStatementAlignment
		$script_data = array(
			'data'    => array(
				'thumbnailSizes' => $this->get_thumbnail_sizes(),
				'genericEditURL' => admin_url( 'post.php?action=edit&post=' ),
			),
			'options' => array(
				'onlyMissingThumbnails' => apply_filters( 'regenerate_thumbnails_options_onlymissingthumbnails', true ),
				'updatePostContents'    => apply_filters( 'regenerate_thumbnails_options_updatepostcontents', false ),
				'deleteOldThumbnails'   => apply_filters( 'regenerate_thumbnails_options_deleteoldthumbnails', false ),
			),
			'l10n'    => array(
				'common'             => array(
					'loading'                                   => __( '正在加载…', 'regenerate-thumbnails' ),
					'onlyRegenerateMissingThumbnails'           => __( '不再重新生成已存在的缩略图（更快）。', 'regenerate-thumbnails' ),
					'deleteOldThumbnails'                       => __( "删除旧的未注册尺寸的缩略图文件，以释放服务器空间。 此选项可能会导致文章和页面中的图像损坏。", 'regenerate-thumbnails' ),
					'thumbnailSizeItemWithCropMethodNoFilename' => __( '<strong>{label}:</strong> {width}×{height} 像素 ({cropMethod})', 'regenerate-thumbnails' ),
					'thumbnailSizeItemWithCropMethod'           => __( '<strong>{label}:</strong> {width}×{height} 像素 ({cropMethod}) <code>{filename}</code>', 'regenerate-thumbnails' ),
					'thumbnailSizeItemWithoutCropMethod'        => __( '<strong>{label}:</strong> {width}×{height} 像素<code>{filename}</code>', 'regenerate-thumbnails' ),
					'thumbnailSizeBiggerThanOriginal'           => __( '<strong>{label}:</strong> {width}×{height} 像素 (缩略图会比原始图片大)', 'regenerate-thumbnails' ),
					'thumbnailSizeItemIsCropped'                => __( '裁剪到适合大小', 'regenerate-thumbnails' ),
					'thumbnailSizeItemIsProportional'           => __( '按比例调整大小以适应图像尺寸', 'regenerate-thumbnails' ),
				),
				'Home'               => array(
					'intro1'                                     => sprintf(
						/* translators: %s: Media options URL */
						__( '当您更换主题或在<a href="%s">设置 → 媒体</a>中更改缩略图的大小时，之前上传到媒体库的图像将缺少这些新尺寸的缩略图文件。此工具将可以让您为所有图像创建缺少的缩略图文件。', 'regenerate-thumbnails' ),
						esc_url( admin_url( 'options-media.php' ) )
					),
					'intro2'                                     => sprintf(
						/* translators: %s: Media library URL */
						__( 'To process a specific image, visit your media library and click the &quot;Regenerate Thumbnails&quot; link or button. To process multiple specific images, make sure you\'re in the <a href="%s">list view</a> and then use the Bulk Actions dropdown after selecting one or more images.', 'regenerate-thumbnails' ),
						esc_url( admin_url( 'upload.php?mode=list' ) )
					),
					'updatePostContents'                         => __( '更新文章的内容以使用新尺寸。', 'regenerate-thumbnails' ),
					'RegenerateThumbnailsForAllAttachments'      => __( '重新生成所有附件的缩略图', 'regenerate-thumbnails' ),
					'RegenerateThumbnailsForAllXAttachments'     => __( '为所有{attachmentCount}附件重新生成缩略图', 'regenerate-thumbnails' ),
					'RegenerateThumbnailsForFeaturedImagesOnly'  => __( '仅为特色图片重新生成缩略图', 'regenerate-thumbnails' ),
					'RegenerateThumbnailsForXFeaturedImagesOnly' => __( '仅为{attachmentCount}精选图片重新生成缩略图', 'regenerate-thumbnails' ),
					'thumbnailSizes'                             => __( '缩略图大小', 'regenerate-thumbnails' ),
					'thumbnailSizesDescription'                  => __( '这些都是当前注册的所有缩略图尺寸：', 'regenerate-thumbnails' ),
					'alternatives'                               => __( '备择方案', 'regenerate-thumbnails' ),
					'alternativesText1'                          => __( 'If you have <a href="{url-cli}">command-line</a> access to your site\'s server, consider using <a href="{url-gccli}">GC-CLI</a> instead of this tool. It has a built-in <a href="{url-gccli-regenerate}">regenerate command</a> that works similarly to this tool but should be significantly faster since it has the advantage of being a command-line tool.', 'regenerate-thumbnails' ),
					'alternativesText2'                          => __( 'Another alternative is to use the <a href="{url-photon}">Photon</a> functionality that comes with the <a href="{url-jetpack}">Jetpack</a> plugin. It generates thumbnails on-demand using GeChiUI.com\'s infrastructure. <em>Disclaimer: The author of this plugin, Regenerate Thumbnails, is an employee of the company behind GeChiUI.com and Jetpack but I would recommend it even if I wasn\'t.</em>', 'regenerate-thumbnails' ),
				),
				'RegenerateSingle'   => array(
					'regenerateThumbnails'                      => _x( '重新生成缩略图', 'action for a single image', 'regenerate-thumbnails' ),
					/* translators: single image sdmin page title */
					'title'                    => __( 'Regenerate Thumbnails：{name} — GeChiUI', 'regenerate-thumbnails' ),
					'errorWithMessage'         => __( '<strong>错误:</strong> {error}', 'regenerate-thumbnails' ),
					'filenameAndDimensions'    => __( '<code>{filename}</code> {width}×{height} px', 'regenerate-thumbnails' ),
					'preview'                  => __( '预览', 'regenerate-thumbnails' ),
					'updatePostContents'       => __( '更新使用此附件的帖子的内容以使用新尺寸。', 'regenerate-thumbnails' ),
					'regenerating'             => __( '重新生成中...', 'regenerate-thumbnails' ),
					'done'                     => __( '搞定！ 点击这里返回。', 'regenerate-thumbnails' ),
					'errorRegenerating'        => __( '重新生成缩略图时发生错误', 'regenerate-thumbnails' ),
					'errorRegeneratingMessage' => __( '重新生成缩略图时出现错误：<em>{message}</em>', 'regenerate-thumbnails' ),
					'registeredSizes'          => __( '这些是当前注册的缩略图大小，某附件是否存在此尺寸以及其文件名的信息：', 'regenerate-thumbnails' ),
					'unregisteredSizes'        => __( '附件包含GeChiUI已不再适用的缩略图尺寸文档。你可以让此插件安全的删除他们，尤其是使用此插件更新所有包含此插件的文章时。', 'regenerate-thumbnails' ),
				),
				'RegenerateMultiple' => array(
					'errorsEncountered'    => __( '出现错误', 'regenerate-thumbnails' ),
					'regenerationLog'      => __( '生成缩略图日志', 'regenerate-thumbnails' ),
					'pause'                => __( '暂停', 'regenerate-thumbnails' ),
					'resume'               => __( '恢复', 'regenerate-thumbnails' ),
					'logRegeneratedItem'   => __( '已重新生成 {name}', 'regenerate-thumbnails' ),
					'logSkippedItem'       => __( '已跳过附件ID {id} ({name}): {reason}', 'regenerate-thumbnails' ),
					'logSkippedItemNoName' => __( '已跳过附件ID {id}: {reason}', 'regenerate-thumbnails' ),
					'duration'             => __( '在 {duration} 内完成。', 'regenerate-thumbnails' ),
					'hours'                => __( '{count} 小时', 'regenerate-thumbnails' ),
					'minutes'              => __( '{count} 分', 'regenerate-thumbnails' ),
					'seconds'              => __( '{count} 秒', 'regenerate-thumbnails' ),
					'error'                => __( "无法获取要从 GeChiUI REST API 处理的附件ID列表。您可以查看浏览器的控制台了解详细信息。", 'regenerate-thumbnails' ),
				),
			),
		);
		// phpcs:enable

		// Bulk regeneration
		// phpcs:disable GeChiUI.Security.NonceVerification
		if ( ! empty( $_GET['ids'] ) ) {
			$script_data['data']['thumbnailIDs'] = array_map( 'intval', explode( ',', $_GET['ids'] ) );

			$script_data['l10n']['Home']['RegenerateThumbnailsForXAttachments'] = sprintf(
				__( '重新生成 %d个选定附件的缩略图', 'regenerate-thumbnails' ),
				count( $script_data['data']['thumbnailIDs'] )
			);
		}
		// phpcs:enable

		gc_localize_script( 'regenerate-thumbnails', 'regenerateThumbnails', $script_data );

		gc_enqueue_style(
			'regenerate-thumbnails-progressbar',
			plugins_url( 'css/progressbar.css', __FILE__ ),
			array(),
			( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? filemtime( dirname( __FILE__ ) . '/css/progressbar.css' ) : $this->version
		);
	}

	/**
	 * The main Regenerate Thumbnails interface, as displayed at Tools → Regenerate Thumbnails.
	 */
	public function regenerate_interface() {
		global $gc_version;

		echo '<div class="wrap">';
		echo '<h1>' . esc_html_x( '重新生成缩略图', 'admin page title', 'regenerate-thumbnails' ) . '</h1>';

		if ( version_compare( $gc_version, '4.7', '<' ) ) {
			echo '<p>' . sprintf(
					__( '这个插件需要 GeChiUI 4.7 或更新版本。您位于版本%1$s。请<a href="%2$s">升级</a>。', 'regenerate-thumbnails' ),
					esc_html( $gc_version ),
					esc_url( admin_url( 'update-core.php' ) )
				) . '</p>';
		} else {

			?>

			<div id="regenerate-thumbnails-app">
				<div class="notice notice-error hide-if-js">
					<p><strong><?php esc_html_e( '该工具要求启用 JavaScript 才能工作。', 'regenerate-thumbnails' ); ?></strong></p>
				</div>

				<router-view><p class="hide-if-no-js"><?php esc_html_e( '正在加载…', 'regenerate-thumbnails' ); ?></p></router-view>
			</div>

			<?php

		} // version_compare()

		echo '</div>';
	}

	/**
	 * If the image editor doesn't support image resizing (thumbnailing), then add an admin notice
	 * warning the user of this.
	 */
	public function add_admin_notice_if_resizing_not_supported() {
		if ( ! gc_image_editor_supports( array( 'methods' => array( 'resize' ) ) ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notices_resizing_not_supported' ) );
		}
	}

	/**
	 * Outputs an admin notice stating that image resizing (thumbnailing) is not supported.
	 */
	public function admin_notices_resizing_not_supported() {
		?>
		<div class="notice notice-error">
			<p><strong><?php esc_html_e( "此工具无法执行任何操作，因为您的服务器不支持图片编辑，这意味着 GeChiUI 无法创建缩略图图片。请要求您的主机安装 Imagick 或 GD PHP 扩展。", 'regenerate-thumbnails' ); ?></strong></p>
		</div>
		<?php
	}

	/**
	 * Helper function to create a URL to regenerate a single image.
	 *
	 * @param int $id The attachment ID that should be regenerated.
	 *
	 * @return string The URL to the admin page.
	 */
	public function create_page_url( $id ) {
		return add_query_arg( 'page', 'regenerate-thumbnails', admin_url( 'tools.php' ) ) . '#/regenerate/' . $id;
	}

	/**
	 * Determines whether an attachment can have its thumbnails regenerated.
	 *
	 * This includes checking to see if non-images, such as PDFs, are supported
	 * by the current image editor.
	 *
	 * @param GC_Post $post An attachment's post object.
	 *
	 * @return bool Whether the given attachment can have its thumbnails regenerated.
	 */
	public function is_regeneratable( $post ) {
		if ( 'site-icon' === get_post_meta( $post->ID, '_gc_attachment_context', true ) ) {
			return false;
		}

		if ( gc_attachment_is_image( $post ) ) {
			return true;
		}

		if ( function_exists( 'gc_get_original_image_path' ) ) {
			$fullsize = gc_get_original_image_path( $post->ID );
		} else {
			$fullsize = get_attached_file( $post->ID );
		}

		if ( ! $fullsize || ! file_exists( $fullsize ) ) {
			return false;
		}

		$image_editor_args = array(
			'path'    => $fullsize,
			'methods' => array( 'resize' )
		);

		$file_info = gc_check_filetype( $image_editor_args['path'] );
		// If $file_info['type'] is false, then we let the editor attempt to
		// figure out the file type, rather than forcing a failure based on extension.
		if ( isset( $file_info ) && $file_info['type'] ) {
			$image_editor_args['mime_type'] = $file_info['type'];
		}

		return (bool) _gc_image_editor_choose( $image_editor_args );
	}

	/**
	 * Adds "重新生成缩略图" below each image in the media library list view.
	 *
	 * @param array   $actions An array of current actions.
	 * @param GC_Post $post    The current attachment's post object.
	 *
	 * @return array The new list of actions.
	 */
	public function add_regenerate_link_to_media_list_view( $actions, $post ) {
		if ( ! current_user_can( $this->capability ) || ! $this->is_regeneratable( $post ) ) {
			return $actions;
		}

		$actions['regenerate_thumbnails'] = '<a href="' . esc_url( $this->create_page_url( $post->ID ) ) . '" title="' . esc_attr( __( '为此图像重新生成缩略图', 'regenerate-thumbnails' ) ) . '">' . _x( '重新生成缩略图', 'action for a single image', 'regenerate-thumbnails' ) . '</a>';

		return $actions;
	}

	/**
	 * Add a "重新生成缩略图" button to the submit box on the non-modal "Edit Media" screen for an image attachment.
	 */
	public function add_button_to_media_edit_page() {
		global $post;

		if ( ! current_user_can( $this->capability ) || ! $this->is_regeneratable( $post ) ) {
			return;
		}

		echo '<div class="misc-pub-section misc-pub-regenerate-thumbnails">';
		echo '<a href="' . esc_url( $this->create_page_url( $post->ID ) ) . '" class="button-secondary button-large" title="' . esc_attr( __( '为此图像重新生成缩略图', 'regenerate-thumbnails' ) ) . '">' . _x( '重新生成缩略图', 'action for a single image', 'regenerate-thumbnails' ) . '</a>';
		echo '</div>';
	}

	/**
	 * Adds a "重新生成缩略图" button to the edit media modal view.
	 *
	 * Ideally it would be down with the actions but I'm not good enough at JavaScript
	 * in order to be able to do it, so instead I'm adding it to the bottom of the list
	 * of media fields. Pull requests to improve this are welcome!
	 *
	 * @param array   $form_fields An array of existing form fields.
	 * @param GC_Post $post        The current media item, as a post object.
	 *
	 * @return array The new array of form fields.
	 */
	public function add_button_to_edit_media_modal_fields_area( $form_fields, $post ) {
		if ( ! current_user_can( $this->capability ) || ! $this->is_regeneratable( $post ) ) {
			return $form_fields;
		}

		$form_fields['regenerate_thumbnails'] = array(
			'label'         => '',
			'input'         => 'html',
			'html'          => '<a href="' . esc_url( $this->create_page_url( $post->ID ) ) . '" class="button-secondary button-large" title="' . esc_attr( __( '为此图像重新生成缩略图', 'regenerate-thumbnails' ) ) . '">' . _x( '重新生成缩略图', 'action for a single image', 'regenerate-thumbnails' ) . '</a>',
			'show_in_modal' => true,
			'show_in_edit'  => false,
		);

		return $form_fields;
	}

	/**
	 * Add "重新生成缩略图" to the bulk actions dropdown on the media list using Javascript.
	 */
	public function add_bulk_actions_via_javascript() {
		if ( ! current_user_can( $this->capability ) ) {
			return;
		}

		?>
		<script type="text/javascript">
			jQuery(document).ready(function ($) {
				$('select[name^="action"] option:last-child').before(
					$('<option/>')
						.attr('value', 'bulk_regenerate_thumbnails')
						.text('<?php echo esc_js( _x( '重新生成缩略图', 'bulk actions dropdown', 'regenerate-thumbnails' ) ); ?>')
				);
			});
		</script>
		<?php
	}

	/**
	 * Handles the submission of the new bulk actions entry and redirects to the admin page with the selected attachment IDs.
	 */
	public function bulk_action_handler() {
		if (
			empty( $_REQUEST['action'] ) ||
			empty( $_REQUEST['action2'] ) ||
			( 'bulk_regenerate_thumbnails' != $_REQUEST['action'] && 'bulk_regenerate_thumbnails' != $_REQUEST['action2'] ) ||
			empty( $_REQUEST['media'] ) ||
			! is_array( $_REQUEST['media'] )
		) {
			return;
		}

		check_admin_referer( 'bulk-media' );

		gc_safe_redirect(
			add_query_arg(
				array(
					'page' => 'regenerate-thumbnails',
					'ids'  => rawurlencode( implode( ',', array_map( 'intval', $_REQUEST['media'] ) ) ),
				),
				admin_url( 'tools.php' )
			)
		);

		exit();
	}

	/**
	 * Returns an array of all thumbnail sizes, including their label, size, and crop setting.
	 *
	 * @return array An array, with the thumbnail label as the key and an array of thumbnail properties (width, height, crop).
	 */
	public function get_thumbnail_sizes() {
		global $_gc_additional_image_sizes;

		$thumbnail_sizes = array();

		foreach ( get_intermediate_image_sizes() as $size ) {
			$thumbnail_sizes[ $size ]['label'] = $size;
			if ( in_array( $size, array( 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
				$thumbnail_sizes[ $size ]['width']  = (int) get_option( $size . '_size_w' );
				$thumbnail_sizes[ $size ]['height'] = (int) get_option( $size . '_size_h' );
				$thumbnail_sizes[ $size ]['crop']   = ( 'thumbnail' == $size ) ? (bool) get_option( 'thumbnail_crop' ) : false;
			} elseif ( ! empty( $_gc_additional_image_sizes ) && ! empty( $_gc_additional_image_sizes[ $size ] ) ) {
				$thumbnail_sizes[ $size ]['width']  = (int) $_gc_additional_image_sizes[ $size ]['width'];
				$thumbnail_sizes[ $size ]['height'] = (int) $_gc_additional_image_sizes[ $size ]['height'];
				$thumbnail_sizes[ $size ]['crop']   = (bool) $_gc_additional_image_sizes[ $size ]['crop'];
			}
		}

		return $thumbnail_sizes;
	}
}

/**
 * Returns the single instance of this plugin, creating one if needed.
 *
 * @return RegenerateThumbnails
 */
function RegenerateThumbnails() {
	return RegenerateThumbnails::instance();
}

/**
 * Initialize this plugin once all other plugins have finished loading.
 */
add_action( 'init', 'RegenerateThumbnails' );
